FlutterAppMarket class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAndroidManufacturer(
) → Future< String?> - 获取 android.os.Build.MANUFACTURER
-
getAndroidModel(
) → Future< String?> - 获取 android.os.Build.MODEL
-
getPackageName(
String brand) → String? -
isInstalled(
String? uri) → Future< bool?> - 获取APP是否安装 1.uri: ios Schemes xxx://com.xx 2.uri: android 包名 3.在Info.plist文件里,找到LSApplicationQueriesSchemes,添加对应APP的Schemes
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openMarket(
{String? schemaUrl, String? updateAppPackageName, String? marketPackageName}) → Future< void> - 打开应用市场
-
openOtherApp(
String? uri) → Future< bool?> - 打开其他app uri: Schemes xxx://com.xx
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited